@@ -32,29 +32,27 @@ import (
 
 var (
 	reviewLong = templates.LongDesc(`Checks which Service Account can create a Pod.
-	The Pod is inferred from the PodTemplateSpec in the provided resource.
-	If no Service Account is provided the one specified in podTemplateSpec.spec.serviceAccountName is used,
-	unless it is empty, in which case "default" is used.
-	If Service Accounts are provided the podTemplateSpec.spec.serviceAccountName is ignored.
+		The Pod is inferred from the PodTemplateSpec in the provided resource.
+		If no Service Account is provided the one specified in podTemplateSpec.spec.serviceAccountName is used,
+		unless it is empty, in which case "default" is used.
+		If Service Accounts are provided the podTemplateSpec.spec.serviceAccountName is ignored.
 	`)
 	reviewExamples = templates.Examples(`# Check whether Service Accounts sa1 and sa2 can admit a Pod with TemplatePodSpec specified in my_resource.yaml
-	# Service Account specified in myresource.yaml file is ignored
-	$ %[1]s -z sa1,sa2 -f my_resource.yaml
+		# Service Account specified in myresource.yaml file is ignored
+		oc adm policy scc-review -z sa1,sa2 -f my_resource.yaml
 
-	# Check whether Service Accounts system:serviceaccount:bob:default can admit a Pod with TemplatePodSpec specified in my_resource.yaml
-	$  %[1]s -z system:serviceaccount:bob:default -f my_resource.yaml
+		# Check whether Service Accounts system:serviceaccount:bob:default can admit a Pod with TemplatePodSpec specified in my_resource.yaml
+		oc adm policy scc-review -z system:serviceaccount:bob:default -f my_resource.yaml
 
-	# Check whether Service Account specified in my_resource_with_sa.yaml can admit the Pod
-	$ %[1]s -f my_resource_with_sa.yaml
+		# Check whether Service Account specified in my_resource_with_sa.yaml can admit the Pod
+		oc adm policy scc-review -f my_resource_with_sa.yaml
 
-	# Check whether default Service Account can admit the Pod, default is taken since no Service Account is defined in myresource_with_no_sa.yaml
-	$  %[1]s -f myresource_with_no_sa.yaml
+		# Check whether default Service Account can admit the Pod, default is taken since no Service Account is defined in myresource_with_no_sa.yaml
+		oc adm policy scc-review -f myresource_with_no_sa.yaml
 	`)
 )
 
 const (
-	ReviewRecommendedName = "scc-review"
-
 	tabWriterMinWidth = 0
 	tabWriterWidth    = 7
 	tabWriterPadding  = 3
@@ -87,13 +85,13 @@ func NewSCCReviewOptions(streams genericclioptions.IOStreams) *SCCReviewOptions
 	}
 }
 
-func NewCmdSccReview(name, fullName string, f kcmdutil.Factory, streams genericclioptions.IOStreams) *cobra.Command {
+func NewCmdSccReview(f kcmdutil.Factory, streams genericclioptions.IOStreams) *cobra.Command {
 	o := NewSCCReviewOptions(streams)
 	cmd := &cobra.Command{
-		Use:     name,
+		Use:     "scc-review",
 		Short:   "Checks which ServiceAccount can create a Pod",
 		Long:    reviewLong,
-		Example: fmt.Sprintf(reviewExamples, fullName),
+		Example: reviewExamples,
 		Run: func(cmd *cobra.Command, args []string) {
 			kcmdutil.CheckErr(o.Complete(f, args, cmd))
 			kcmdutil.CheckErr(o.Run(args))
